@@ -17,11 +17,11 @@ Config::Abstraction - Configuration Abstraction Layer
 
 =head1 VERSION
 
-Version 0.17
+Version 0.18
 
 =cut
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 =head1 SYNOPSIS
 
@@ -190,7 +190,8 @@ Options:
 
 =item * C<config_dirs>
 
-An arrayref of directories to look for configuration files (default: C<[$HOME/.conf]>, C<[$DOCUMENT_ROOT/conf]>, or C<['conf']>).
+An arrayref of directories to look for configuration files (default: C<$CONFIG_DIR>, C<[$HOME/.conf]>, C<[$DOCUMENT_ROOT/conf]>, or C<['conf']>).
+Considers the file C<default> before looking at C<config_file> and C<config_files>.
 
 =item * C<config_file>
 
@@ -262,9 +263,13 @@ sub new
 			} elsif($ENV{'DOCUMENT_ROOT'}) {
 				push @{$params->{'config_dirs'}},
 					File::Spec->catdir($ENV{'DOCUMENT_ROOT'}, 'conf'),
-					File::Spec->catdir($ENV{'HOME'}, 'config');
+					File::Spec->catdir($ENV{'DOCUMENT_ROOT'}, 'config');
+			}
+			if(my $dir = $ENV{'CONFIG_DIR'}) {
+				push @{$params->{'config_dirs'}}, $dir;
+			} else {
+				push @{$params->{'config_dirs'}}, 'conf', 'config';
 			}
-			push @{$params->{'config_dirs'}}, 'conf', 'config';
 		}
 	}
 
@@ -376,7 +381,7 @@ sub _load_config
 		}
 
 		# Put $self->{config_file} through all parsers, ignoring all errors, then merge that in
-		for my $config_file ($self->{'config_file'}, @{$self->{'config_files'}}) {
+		for my $config_file ('default', $self->{'config_file'}, @{$self->{'config_files'}}) {
 			next unless defined($config_file);
 			my $path = length($dir) ? File::Spec->catfile($dir, $config_file) : $config_file;
 			if($logger) {
